The Foos and The Bars - Code

1. # Unix Exit Status Code Reference

   I always find myself constantly Googling the list of unix status codes (typically defined in `sysexits.h`).

       0 # successful termination 64 # base value for error messages
       64 # command line usage error
       65 # data format error
       66 # cannot open input
       67 # addressee unknown
       68 # host name unknown
       69 # service unavailable
       70 ...

   Read more

## blogroll

- About
- Resume

## social

- atom feed
- GitHub
- Twitter